@@ -281,6 +281,20 @@ xfpm_backlight_button_pressed_cb (XfpmButton *button, XfpmButtonKey type, XfpmBa
     xfpm_backlight_show (backlight, level);
 }
 
+static void
+xfpm_backlight_handle_brightness_keys_changed (XfpmBacklight *backlight)
+{
+  gboolean handle_keys = FALSE;
+
+  g_object_get (G_OBJECT (backlight->priv->conf),
+                HANDLE_BRIGHTNESS_KEYS, &handle_keys,
+                NULL);
+
+  XFPM_DEBUG ("handle_brightness_keys changed to %s", handle_keys ? "TRUE" : "FALSE");
+
+  xfpm_button_set_handle_brightness_keys (backlight->priv->button, handle_keys);
+}
+
 static void
 xfpm_backlight_brightness_on_ac_settings_changed (XfpmBacklight *backlight)
 {
@@ -438,6 +452,9 @@ xfpm_backlight_init (XfpmBacklight *backlight)
             BRIGHTNESS_SWITCH,
             backlight->priv->brightness_switch,
             NULL);
+    xfpm_button_set_handle_brightness_keys (backlight->priv->button, handle_keys);
+    g_signal_connect_object (backlight->priv->conf, "notify::" HANDLE_BRIGHTNESS_KEYS,
+                             G_CALLBACK (xfpm_backlight_handle_brightness_keys_changed), backlight, G_CONNECT_SWAPPED);
 
     g_signal_connect_object (backlight->priv->idle, "alarm-expired",
                              G_CALLBACK (xfpm_backlight_alarm_timeout_cb), backlight, 0);
